๐ backoff-config โ๏ธ
This crate enables declarative configuration of backon retry crate strategies via environment variables or configuration files by:
-
Unifying the backoff strategies provided by the backon retry crate into a single enum (see BackoffConfig).
-
Implementing serde::Deserialize to support loading strategies from various configuration sources. std::time::Duration values are deserialized using human-readable formats (e.g.
5s,150 ms).
Modules
- defaults
- Contains the defaults used by the crate::BackoffConfig.
Structs
- Constant
Backoff Config - Configuration for Backoff::Constant.
- Exponential
Backoff Config - Configuration for Backoff::Exponential.
- Fibonacci
Backoff Config - Configuration for Backoff::Fibonacci.
Enums
- Backoff
- Supported backoffs.
- Backoff
Config - Configuration for Backoff.